@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '2.006001'; # VERSION
+our $VERSION = '2.006002'; # VERSION
 
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
@@ -126,13 +126,15 @@ no Moose;
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::Test::PodSpelling - Author tests for POD spelling
 
 =head1 VERSION
 
-version 2.006001
+version 2.006002
 
 =head1 SYNOPSIS
 
@@ -218,6 +220,10 @@ feature.
 
 =item *
 
+Alexandr Ciornii <alexchorny@gmail.com>
+
+=item *
+
 Breno G. de Oliveira <garu@cpan.org>
 
 =item *
